print("import: 'phonenumbers'")
import phonenumbers

print("import: 'phonenumbers.carrierdata'")
import phonenumbers.carrierdata

print("import: 'phonenumbers.data'")
import phonenumbers.data

print("import: 'phonenumbers.geodata'")
import phonenumbers.geodata

print("import: 'phonenumbers.shortdata'")
import phonenumbers.shortdata

print("import: 'phonenumbers.tzdata'")
import phonenumbers.tzdata

